@@ -1,5 +1,5 @@
 /* Formatted output to a stream.
-   Copyright (C) 2004, 2006-2017 Free Software Foundation, Inc.
+   Copyright (C) 2004, 2006-2007 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,6 +29,11 @@
 #include "fseterr.h"
 #include "vasnprintf.h"
 
+/* Some systems, like OSF/1 4.0 and Woe32, don't have EOVERFLOW.  */
+#ifndef EOVERFLOW
+# define EOVERFLOW E2BIG
+#endif
+
 /* Print formatted output to the stream FP.
    Return string length of formatted string.  On error, return a negative
    value.  */
@@ -52,17 +57,14 @@ vfprintf (FILE *fp, const char *format, va_list args)
   if (fwrite (output, 1, len, fp) < len)
     {
       if (output != buf)
-        {
-          int saved_errno = errno;
-          free (output);
-          errno = saved_errno;
-        }
+	{
+	  int saved_errno = errno;
+	  free (output);
+	  errno = saved_errno;
+	}
       return -1;
     }
 
-  if (output != buf)
-    free (output);
-
   if (len > INT_MAX)
     {
       errno = EOVERFLOW;
