@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 2007, 2009, 2011 Free Software Foundation, Inc.
+   Copyright (C) 2007 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,30 +36,27 @@
 #ifndef DATA_CASEREADER_PROVIDER_H
 #define DATA_CASEREADER_PROVIDER_H 1
 
-#include "data/casereader.h"
+#include <data/casereader.h>
 
 /* Casereader class for sequential data sources. */
 struct casereader_class
   {
     /* Mandatory.
 
-       Reads the next case from READER.  If successful, returns
-       the case and advances READER, so that the next call to
-       this function will read the following case.  The case just
-       read will never be read again by a call to this function
-       for READER.
+       Reads the next case from READER into case C, which the
+       casereader must create and which the client is responsible
+       for destroying.  If successful, returns true and advances
+       READER to the next case, so that the next call to this
+       function will read the next case.  The case just read will
+       never be read again by a call to this function for READER.
 
-       If a case is successfully returned, the client is
-       responsible for calling case_unref upon it when it is no
-       longer needed.
-
-       At end of file or upon an I/O error, returns a null
-       pointer.  After null is returned once, this function will
-       not be called again for the given READER.
+       At end of file or upon an I/O error, returns false.  After
+       false is returned once, this function will not be called
+       again for the given READER.
 
        If an I/O error occurs, this function should call
        casereader_force_error on READER. */
-    struct ccase *(*read) (struct casereader *reader, void *aux);
+    bool (*read) (struct casereader *reader, void *aux, struct ccase *c);
 
     /* Mandatory.
 
@@ -91,31 +88,30 @@ struct casereader_class
        (But it might be easier to use the random-access
        casereader wrapper instead.)
 
-       Reads and returns the case at 0-based offset IDX from the
-       beginning of READER.  If a case is successfully returned,
-       the client is responsible for calling case_unref upon it
-       when it is no longer needed.
+       Reads the case at 0-based offset IDX from the beginning of
+       READER into case C, which the casereader must create and
+       which the client is responsible for destroying.
 
-       At end of file or upon an I/O error, returns a null
-       pointer.  If this function returns null, then it will
-       never be called again for an equal or greater value of
-       IDX, and the "read" member function will never be called
-       to advance as far as IDX cases further into the
-       casereader.  That is, returning null indicates that the
-       casereader has fewer than IDX cases left.
+       At end of file or upon an I/O error, returns false.  If
+       this function returns false, then it will never be called
+       again for an equal or greater value of IDX, and the "read"
+       member function will never be called to advance as far as
+       IDX cases further into the casereader.  That is, returning
+       false indicates that the casereader has fewer than IDX
+       cases left.
 
        If an I/O error occurs, this function should call
        casereader_force_error on READER. */
-    struct ccase *(*peek) (struct casereader *reader, void *aux,
-                           casenumber idx);
+    bool (*peek) (struct casereader *reader, void *aux, casenumber idx,
+                  struct ccase *c);
   };
 
 struct casereader *
 casereader_create_sequential (const struct taint *,
-                              const struct caseproto *, casenumber n_cases,
+                              size_t value_cnt, casenumber case_cnt,
                               const struct casereader_class *, void *);
 
-void *casereader_dynamic_cast (struct casereader *, const struct casereader_class *);
+void *casereader_dynamic_cast (struct casereader *, struct casereader_class *);
 
 /* Casereader class for random-access data sources. */
 struct casereader_random_class
@@ -123,22 +119,21 @@ struct casereader_random_class
     /* Mandatory.
 
        Reads the case at 0-based offset IDX from the beginning of
-       READER.  If a case is successfully returned, the client is
-       responsible for calling case_unref upon it when it is no
-       longer needed.
+       READER into case C, which the casereader must create and
+       which the client is responsible for destroying.
 
-       At end of file or upon an I/O error, returns a null
-       pointer.  If this function returns null, then it will
-       never be called again for an equal or greater value of
-       IDX, and the "read" member function will never be called
-       to advance as far as IDX cases further into the
-       casereader.  That is, returning null indicates that the
-       casereader has fewer than IDX cases.
+       At end of file or upon an I/O error, returns false.  If
+       this function returns false, then it will never be called
+       again for an equal or greater value of IDX, and the "read"
+       member function will never be called to advance as far as
+       IDX cases further into the casereader.  That is, returning
+       false indicates that the casereader has fewer than IDX
+       cases.
 
        If an I/O error occurs, this function should call
        casereader_force_error on READER. */
-    struct ccase *(*read) (struct casereader *reader, void *aux,
-                           casenumber idx);
+    bool (*read) (struct casereader *reader, void *aux, casenumber idx,
+                  struct ccase *c);
 
     /* Mandatory.
 
@@ -148,19 +143,19 @@ struct casereader_random_class
        function should call casereader_force_error on READER. */
     void (*destroy) (struct casereader *reader, void *aux);
 
-    /* Optional.
+    /* Mandatory.
 
-       A call to this function tells the callee that the N
+       A call to this function tells the callee that the CNT
        cases at the beginning of READER will never be read again.
        The casereader implementation should free any resources
        associated with those cases.  After this function returns,
        the IDX argument in future calls to the "read" function
        will be relative to remaining cases. */
-    void (*advance) (struct casereader *reader, void *aux, casenumber n);
+    void (*advance) (struct casereader *reader, void *aux, casenumber cnt);
   };
 
 struct casereader *
-casereader_create_random (const struct caseproto *, casenumber n_cases,
+casereader_create_random (size_t value_cnt, casenumber case_cnt,
                           const struct casereader_random_class *, void *aux);
 
 #endif /* data/casereader-provider.h */
