@@ -1,20 +1,18 @@
-/* PSPP - computes sample statistics.
+/* PSPP - a program for statistical analysis.
    Copyright (C) 1997-9, 2000, 2006 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA. */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <config.h>
 
@@ -209,6 +207,16 @@ fmt_for_output_from_input (const struct fmt_spec *input)
   return output;
 }
 
+/* Returns the default format for the given WIDTH: F8.2 format
+   for a numeric value, A format for a string value. */
+struct fmt_spec
+fmt_default_for_width (int width)
+{
+  return (width == 0
+          ? fmt_for_output (FMT_F, 8, 2)
+          : fmt_for_output (FMT_A, width, 0));
+}
+
 /* Checks whether SPEC is valid as an input format (if FOR_INPUT)
    or an output format (otherwise) and returns nonzero if so.
    Otherwise, emits an error message and returns zero. */
@@ -366,10 +374,32 @@ fmt_to_string (const struct fmt_spec *f, char buffer[FMT_STRING_LEN_MAX + 1])
 /* Returns true if A and B are identical formats,
    false otherwise. */
 bool
-fmt_equal (const struct fmt_spec *a, const struct fmt_spec *b) 
+fmt_equal (const struct fmt_spec *a, const struct fmt_spec *b)
 {
   return a->type == b->type && a->w == b->w && a->d == b->d;
 }
+
+/* Adjusts FMT to be valid for a value of the given WIDTH. */
+void
+fmt_resize (struct fmt_spec *fmt, int width) 
+{
+  if ((width > 0) != fmt_is_string (fmt->type))
+    {
+      /* Changed from numeric to string or vice versa.  Set to
+         default format for new width. */
+      *fmt = fmt_default_for_width (width);
+    }
+  else if (width > 0)
+    {
+      /* Changed width of string.  Preserve format type, adjust
+         width. */
+      fmt->w = fmt->type == FMT_AHEX ? width * 2 : width;
+    }
+  else 
+    {
+      /* Still numeric. */
+    }
+}
 
 /* Describes a display format. */
 struct fmt_desc
@@ -494,7 +524,7 @@ fmt_is_numeric (enum fmt_type type)
    category.  Thus, the return value may be tested for equality
    or compared bitwise against a mask of FMT_CAT_* values. */
 enum fmt_category
-fmt_get_category (enum fmt_type type) 
+fmt_get_category (enum fmt_type type)
 {
   return get_fmt_desc (type)->category;
 }
@@ -504,7 +534,7 @@ fmt_get_category (enum fmt_type type)
 enum fmt_type
 fmt_input_to_output (enum fmt_type type)
 {
-  switch (fmt_get_category (type)) 
+  switch (fmt_get_category (type))
     {
     case FMT_CAT_STRING:
       return FMT_A;
@@ -602,13 +632,13 @@ fmt_dollar_template (const struct fmt_spec *fmt)
   for (c = MAX (fmt->w - fmt->d - 1, 0); c > 0; )
     {
       ds_put_char (&s, '#');
-      if (--c % 4 == 0 && c > 0) 
+      if (--c % 4 == 0 && c > 0)
         {
           ds_put_char (&s, fmt_grouping_char (fmt->type));
           --c;
         }
     }
-  if (fmt->d > 0) 
+  if (fmt->d > 0)
     {
       ds_put_char (&s, fmt_decimal_char (fmt->type));
       ds_put_char_multiple (&s, '#', fmt->d);
