@@ -24,12 +24,13 @@
 #include <data/format.h>
 #include <data/value.h>
 #include <data/variable.h>
-#include <libpspp/alloc.h>
 #include <libpspp/compiler.h>
 #include <libpspp/hash.h>
 #include <libpspp/message.h>
 #include <libpspp/str.h>
 
+#include "xalloc.h"
+
 static hsh_compare_func compare_int_val_lab;
 static hsh_hash_func hash_int_val_lab;
 static hsh_free_func free_int_val_lab;
