@@ -37,7 +37,6 @@
 #include <language/data-io/file-handle.h>
 #include <language/lexer/lexer.h>
 #include <language/lexer/variable-parser.h>
-#include <libpspp/alloc.h>
 #include <libpspp/assertion.h>
 #include <libpspp/compiler.h>
 #include <libpspp/hash.h>
@@ -46,6 +45,10 @@
 #include <libpspp/str.h>
 #include <libpspp/taint.h>
 
+#include "get-data.h"
+
+#include "xalloc.h"
+
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
 
@@ -72,6 +75,11 @@ parse_read_command (struct lexer *lexer, struct dataset *ds, enum reader_command
   struct dictionary *dict = NULL;
   struct case_map *map = NULL;
 
+  if ( type == GET_CMD && lex_match_id (lexer, "DATA") )
+    {
+      return parse_get_data_command (lexer, ds);
+    }
+
   for (;;)
     {
       lex_match (lexer, '/');
@@ -80,6 +88,7 @@ parse_read_command (struct lexer *lexer, struct dataset *ds, enum reader_command
 	{
 	  lex_match (lexer, '=');
 
+          fh_unref (fh);
 	  fh = fh_parse (lexer, FH_REF_FILE | FH_REF_SCRATCH);
 	  if (fh == NULL)
             goto error;
@@ -132,9 +141,11 @@ parse_read_command (struct lexer *lexer, struct dataset *ds, enum reader_command
 
   proc_set_active_file (ds, reader, dict);
 
+  fh_unref (fh);
   return CMD_SUCCESS;
 
  error:
+  fh_unref (fh);
   casereader_destroy (reader);
   if (dict != NULL)
     dict_destroy (dict);
@@ -360,9 +371,11 @@ parse_write_command (struct lexer *lexer, struct dataset *ds,
                                            map);
   dict_destroy (dict);
 
+  fh_unref (handle);
   return writer;
 
  error:
+  fh_unref (handle);
   casewriter_destroy (writer);
   dict_destroy (dict);
   case_map_destroy (map);
@@ -563,10 +576,10 @@ rename_variables (struct lexer *lexer, struct dictionary *dict)
 	goto done;
       if (nn != nv)
 	{
-	  msg (SE, _("Number of variables on left side of `=' (%d) does not "
-                     "match number of variables on right side (%d), in "
+	  msg (SE, _("Number of variables on left side of `=' (%zu) does not "
+                     "match number of variables on right side (%zu), in "
                      "parenthesized group %d of RENAME subcommand."),
-	       (unsigned) (nv - old_nv), (unsigned) (nn - old_nv), group);
+	       nv - old_nv, nn - old_nv, group);
 	  goto done;
 	}
       if (!lex_force_match (lexer, ')'))
@@ -1081,6 +1094,7 @@ mtf_close_all_files (struct mtf_proc *mtf)
 
   ll_for_each_preremove (file, struct mtf_file, ll, &mtf->files)
     {
+      fh_unref (file->handle);
       casereader_destroy (file->reader);
       free (file->by);
       dict_destroy (file->dict);
