@@ -22,18 +22,17 @@
 #include <limits.h>
 #include <math.h>
 #include <stdarg.h>
+#include <stdint.h>
 #include <stdlib.h>
-#include <libpspp/alloc.h>
 #include <libpspp/assertion.h>
 #include <language/command.h>
 #include <libpspp/message.h>
-#include <libpspp/magic.h>
 #include <data/settings.h>
 #include <libpspp/getl.h>
 #include <libpspp/str.h>
 #include <output/journal.h>
 
-#include "size_max.h"
+#include "xalloc.h"
 
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
@@ -513,8 +512,7 @@ bool
 lex_is_integer (struct lexer *lexer)
 {
   return (lex_is_number (lexer)
-	  && lexer->tokval != NOT_LONG
-	  && lexer->tokval >= LONG_MIN
+	  && lexer->tokval > LONG_MIN
 	  && lexer->tokval <= LONG_MAX
 	  && floor (lexer->tokval) == lexer->tokval);
 }
@@ -1071,9 +1069,9 @@ convert_numeric_string_to_char_string (struct lexer *lexer,
 
   byte_cnt = ds_length (&lexer->tokstr) / chars_per_byte;
   if (ds_length (&lexer->tokstr) % chars_per_byte)
-    msg (SE, _("String of %s digits has %d characters, which is not a "
+    msg (SE, _("String of %s digits has %zu characters, which is not a "
 	       "multiple of %d."),
-	 base_name, (int) ds_length (&lexer->tokstr), chars_per_byte);
+	 base_name, ds_length (&lexer->tokstr), chars_per_byte);
 
   p = ds_cstr (&lexer->tokstr);
   for (i = 0; i < byte_cnt; i++)
@@ -1209,8 +1207,8 @@ finish:
 
   if (ds_length (&lexer->tokstr) > 255)
     {
-      msg (SE, _("String exceeds 255 characters in length (%d characters)."),
-	   (int) ds_length (&lexer->tokstr));
+      msg (SE, _("String exceeds 255 characters in length (%zu characters)."),
+	   ds_length (&lexer->tokstr));
       ds_truncate (&lexer->tokstr, 255);
     }
 
