@@ -26,7 +26,6 @@
 #include <data/dictionary.h>
 #include <data/procedure.h>
 #include <data/variable.h>
-#include <libpspp/alloc.h>
 #include <libpspp/assertion.h>
 #include <libpspp/bit-vector.h>
 #include <libpspp/hash.h>
@@ -35,6 +34,8 @@
 #include <libpspp/pool.h>
 #include <libpspp/str.h>
 
+#include "xalloc.h"
+
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
 
