@@ -30,15 +30,14 @@
 #include <language/lexer/lexer.h>
 #include <language/lexer/variable-parser.h>
 #include <language/lexer/range-parser.h>
-#include <libpspp/alloc.h>
 #include <libpspp/assertion.h>
 #include <libpspp/compiler.h>
-#include <libpspp/magic.h>
-#include <libpspp/message.h>
 #include <libpspp/message.h>
 #include <libpspp/pool.h>
 #include <libpspp/str.h>
 
+#include "xalloc.h"
+
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
 
@@ -437,10 +436,10 @@ parse_dst_vars (struct lexer *lexer, struct recode_trns *trns,
 
       if (name_cnt != trns->var_cnt)
         {
-          msg (SE, _("%u variable(s) cannot be recoded into "
-                     "%u variable(s).  Specify the same number "
+          msg (SE, _("%zu variable(s) cannot be recoded into "
+                     "%zu variable(s).  Specify the same number "
                      "of variables as source and target variables."),
-               (unsigned) trns->var_cnt, (unsigned) name_cnt);
+               trns->var_cnt, name_cnt);
           return false;
         }
 
