@@ -19,15 +19,14 @@
 #include "str.h"
 
 #include <ctype.h>
-#include <limits.h>
+#include <stdint.h>
 #include <stdlib.h>
 
-#include <libpspp/alloc.h>
 #include <libpspp/message.h>
 #include <libpspp/pool.h>
 
 #include "minmax.h"
-#include "size_max.h"
+#include "xalloc.h"
 #include "xsize.h"
 
 /* Reverses the order of NBYTES bytes at address P, thus converting
