@@ -19,10 +19,11 @@
 #include <assert.h>
 #include <math.h>
 #include <stdlib.h>
-#include <libpspp/alloc.h>
 #include <libpspp/misc.h>
 #include <data/value.h>
 
+#include "xalloc.h"
+
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
 
