@@ -37,11 +37,17 @@
 #include "compute-dialog.h"
 #include "goto-case-dialog.h"
 #include "find-dialog.h"
+#include "rank-dialog.h"
 #include "comments-dialog.h"
 #include "variable-info-dialog.h"
+#include "descriptives-dialog.h"
 #include "dict-display.h"
 #include "clipboard.h"
 
+
+#include "oneway-anova-dialog.h"
+#include "t-test-independent-samples-dialog.h"
+
 #define _(msgid) gettext (msgid)
 #define N_(msgid) msgid
 
@@ -585,6 +591,25 @@ new_data_editor (void)
   g_signal_connect (de->invoke_compute_dialog, "activate",
 		    G_CALLBACK (compute_dialog), de);
 
+  de->invoke_oneway_anova_dialog =
+    gtk_action_new ("oneway-anova",
+		    _("Oneway _ANOVA"),
+		    _("Perform one way analysis of variance"),
+		    NULL);
+
+  g_signal_connect (de->invoke_oneway_anova_dialog, "activate",
+		    G_CALLBACK (oneway_anova_dialog), de);
+
+  de->invoke_t_test_independent_samples_dialog =
+    gtk_action_new ("t-test-independent-samples",
+		    _("_Independent Samples T Test"),
+		    _("Calculate T Test for samples from independent groups"),
+		    NULL);
+
+  g_signal_connect (de->invoke_t_test_independent_samples_dialog, "activate",
+		    G_CALLBACK (t_test_independent_samples_dialog), de);
+
+
   de->invoke_comments_dialog =
     gtk_action_new ("commments-dialog",
 		    _("Data File Comments"),
@@ -604,6 +629,16 @@ new_data_editor (void)
 		    G_CALLBACK (find_dialog), de);
 
 
+  de->invoke_rank_dialog  =
+    gtk_action_new ("rank-dialog",
+		    _("Ran_k Cases"),
+		    _("Rank Cases"),
+		    "pspp-rank-cases");
+
+  g_signal_connect (de->invoke_rank_dialog, "activate",
+		    G_CALLBACK (rank_dialog), de);
+
+
   de->invoke_variable_info_dialog  =
     gtk_action_new ("variable-info-dialog",
 		    _("Variables"),
@@ -613,6 +648,15 @@ new_data_editor (void)
   g_signal_connect (de->invoke_variable_info_dialog, "activate",
 		    G_CALLBACK (variable_info_dialog), de);
 
+  de->invoke_descriptives_dialog =
+    gtk_action_new ("descriptives-dialog",
+		    _("_Descriptives"),
+		    _("Calculate descriptive statistics (mean, variance, ...)"),
+		    "pspp-descriptives");
+
+  g_signal_connect (de->invoke_descriptives_dialog, "activate",
+		    G_CALLBACK (descriptives_dialog), de);
+
   e->window = GTK_WINDOW (get_widget_assert (de->xml, "data_editor"));
 
   g_signal_connect_swapped (get_widget_assert (de->xml,"file_new_data"),
@@ -697,6 +741,10 @@ new_data_editor (void)
 			    get_widget_assert (de->xml, "button-find")
 			    );
 
+  gtk_action_connect_proxy (de->invoke_rank_dialog,
+			    get_widget_assert (de->xml, "transform_rank")
+			    );
+
   gtk_action_connect_proxy (de->invoke_weight_cases_dialog,
 			    get_widget_assert (de->xml, "data_weight-cases")
 			    );
@@ -721,6 +769,18 @@ new_data_editor (void)
 			    get_widget_assert (de->xml, "transform_compute")
 			    );
 
+  gtk_action_connect_proxy (de->invoke_t_test_independent_samples_dialog,
+			    get_widget_assert (de->xml,
+					       "indep-t-test")
+			    );
+
+
+  gtk_action_connect_proxy (de->invoke_oneway_anova_dialog,
+			    get_widget_assert (de->xml,
+					       "oneway-anova")
+			    );
+
+
   gtk_action_connect_proxy (de->invoke_comments_dialog,
 			    get_widget_assert (de->xml, "utilities_comments")
 			    );
@@ -729,6 +789,10 @@ new_data_editor (void)
 			    get_widget_assert (de->xml, "utilities_variables")
 			    );
 
+  gtk_action_connect_proxy (de->invoke_descriptives_dialog,
+			    get_widget_assert (de->xml, "analyze_descriptives")
+			    );
+
   g_signal_connect (get_widget_assert (de->xml,"help_about"),
 		    "activate",
 		    G_CALLBACK (about_new),
