@@ -1,5 +1,5 @@
 /* PSPPIRE - a graphical user interface for PSPP.
-   Copyright (C) 2007, 2011, 2013  Free Software Foundation
+   Copyright (C) 2007  Free Software Foundation
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,13 +19,18 @@
 #define VAR_DISPLAY 1
 
 #include <glib.h>
-#include <data/variable.h>
-#include "psppire-dict.h"
 
 struct variable;
 
-#define n_ALIGNMENTS 3
 
-gchar *missing_values_to_string (const struct variable *pv, GError **err);
+gchar * name_to_string (const struct variable *var, GError **err);
+
+
+gchar * missing_values_to_string (const struct variable *pv, GError **err);
+
+gchar * measure_to_string (const struct variable *var, GError **err);
+
+gchar * label_to_string (const struct variable *var, GError **err);
+
 
 #endif
