@@ -1,21 +1,18 @@
-/*
-    PSPPIRE --- A Graphical User Interface for PSPP
+/* PSPPIRE - a graphical user interface for PSPP.
     Copyright (C) 2005, 2006  Free Software Foundation
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA. */
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 
 /*  This module describes the behaviour of the Variable Type dialog box used
@@ -46,7 +43,7 @@ struct tgs
 
 
 struct format_opt {
-  gchar desc[18];
+  gchar desc[21];
   struct fmt_spec spec;
 };
 
@@ -69,7 +66,8 @@ static const struct format_opt format_option[] =
     { "mmm yy",      {FMT_MOYR, 6, 0} },
     { "dd WK yyyy",  {FMT_WKYR, 10, 0} },
     { "dd WK yy",    {FMT_WKYR, 8, 0} },
-    { "dd-mmm-yyyy HH:MM", {FMT_DATETIME, 17, 0}}
+    { "dd-mmm-yyyy HH:MM", {FMT_DATETIME, 17, 0}},
+    { "dd-mmm-yyyy HH:MM:SS", {FMT_DATETIME, 20, 0}}
   };
 
 
@@ -175,6 +173,7 @@ on_toggle_2 (GtkToggleButton *togglebutton, gpointer user_data)
   switch (dialog->active_button)
     {
     case BUTTON_STRING:
+      gtk_widget_show (dialog->entry_width);
       gtk_widget_show (dialog->width_decimals);
       gtk_widget_hide (dialog->label_decimals);
       gtk_widget_hide (dialog->entry_decimals);
