@@ -55,7 +55,7 @@ mkdir -p $TEMPDIR
 cd $TEMPDIR
 
 activity="create program"
-cat > $TEMPDIR/foo.sps <<EOF
+cat > $TESTFILE <<EOF
 INPUT PROGRAM.
 	LOOP #I=1 TO 50000.
 		COMPUTE X=NORMAL(10).
@@ -71,7 +71,7 @@ EOF
 if [ $? -ne 0 ] ; then no_result ; fi
 
 activity="run program"
-$SUPERVISOR $PSPP -o raw-ascii -e /dev/null $TEMPDIR/foo.sps 
+$SUPERVISOR $PSPP --testing-mode -e /dev/null $TESTFILE
 if [ $? -ne 0 ] ; then fail ; fi
 
 pass;
