@@ -22,10 +22,6 @@ export STAT_CONFIG_PATH
 
 cleanup()
 {
-     if [ x"$PSPP_TEST_NO_CLEANUP" != x ] ; then 
-	echo "NOT cleaning $TEMPDIR" 
-	return ; 
-     fi
      cd /
      rm -rf $TEMPDIR
 }
@@ -166,8 +162,7 @@ $SUPERVISOR $PSPP --testing-mode $TESTFILE -e /dev/null
 if [ $? -ne 0 ] ; then no_result ; fi
 
 activity="compare output"
-perl -pi -e 's/^\s*$//g' $TEMPDIR/pspp.list
-diff -b pspp.list - << EOF
+diff -b -B pspp.list - << EOF
        X        Y
 -------- --------
     1.00     2.00
@@ -175,6 +170,7 @@ diff -b pspp.list - << EOF
     3.00     4.00
     4.00     5.00
     5.00     6.00
+
 X        Y
 - --------
 1     3.00
@@ -182,6 +178,7 @@ X        Y
 3     5.00
 4     6.00
 5     7.00
+
 X        Y
 - --------
 1     4.00
